package com.bonus.canteen.core.alloc.service.impl;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.bonus.canteen.core.alloc.domain.*;
import com.bonus.canteen.core.alloc.mapper.AllocCanteenMapper;
import com.bonus.canteen.core.alloc.mapper.AllocStallMapper;
import com.bonus.canteen.core.utils.BnsConstants;
import com.bonus.common.core.exception.ServiceException;
import com.bonus.common.core.utils.DateUtils;
import com.bonus.common.houqin.constant.GlobalConstants;
import com.bonus.common.houqin.constant.LeConstants;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.canteen.core.alloc.service.IAllocCanteenService;

/**
 * 食堂信息Service业务层处理
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Service
public class AllocCanteenServiceImpl implements IAllocCanteenService {
    @Autowired
    private AllocCanteenMapper allocCanteenMapper;
    @Autowired
    private AllocStallMapper allocStallMapper;

    /**
     * 查询食堂信息
     * 
     * @param canteenId 食堂信息主键
     * @return 食堂信息
     */
    @Override
    public AllocCanteen selectAllocCanteenByCanteenId(Long canteenId) {
        return allocCanteenMapper.selectAllocCanteenByCanteenId(canteenId);
    }

    /**
     * 查询食堂信息列表
     * 
     * @param allocCanteen 食堂信息
     * @return 食堂信息
     */
    @Override
    public List<AllocCanteen> selectAllocCanteenList(AllocCanteen allocCanteen) {
        return allocCanteenMapper.selectAllocCanteenList(allocCanteen);
    }

    /**
     * 新增食堂信息
     * 
     * @param allocCanteen 食堂信息
     * @return 结果
     */
    @Override
    public int insertAllocCanteen(AllocCanteen allocCanteen) {
        allocCanteen.setCreateTime(DateUtils.getNowDate());
        allocCanteen.setIfReserve(BnsConstants.COMMON_YES); //默认开启预订餐
        try {
            AllocCanteen checkResult = allocCanteenMapper.selectAllocCanteenByCanteenName(allocCanteen);
            if (Objects.nonNull(checkResult)) {
                throw new ServiceException("该区域食堂名称已存在");
            }
            return allocCanteenMapper.insertAllocCanteen(allocCanteen);
        } catch (Exception e) {
            throw new ServiceException(e.getMessage());
        }
    }

    /**
     * 修改食堂信息
     * 
     * @param allocCanteen 食堂信息
     * @return 结果
     */
    @Override
    public int updateAllocCanteen(AllocCanteen allocCanteen) {
        allocCanteen.setUpdateTime(DateUtils.getNowDate());
        try {
            List<AllocCanteen> allCanteenList = allocCanteenMapper.selectAllocCanteenList(new AllocCanteen());
            List<String> otherCanteenNameList = allCanteenList.stream().filter(item -> !item.getCanteenId().equals(allocCanteen.getCanteenId()))
                    .filter(item -> item.getAreaId().equals(allocCanteen.getAreaId()))
                    .map(AllocCanteen::getCanteenName).collect(Collectors.toList());
            if (otherCanteenNameList.contains(allocCanteen.getCanteenName())) {
                throw new ServiceException("该区域食堂名称已存在");
            }
            return allocCanteenMapper.updateAllocCanteen(allocCanteen);
        } catch (Exception e) {
            throw new ServiceException(e.getMessage());
        }
    }

    /**
     * 批量删除食堂信息
     * 
     * @param canteenIds 需要删除的食堂信息主键
     * @return 结果
     */
    @Override
    public int deleteAllocCanteenByCanteenIds(Long[] canteenIds) {
        int count = allocStallMapper.selectAllocStallCountByCanteenIds(canteenIds);
        if (count > 0) {
            throw new ServiceException("食堂含有档口信息，不能删除");
        }
        return allocCanteenMapper.deleteAllocCanteenByCanteenIds(canteenIds);
    }

    /**
     * 删除食堂信息信息
     * 
     * @param canteenId 食堂信息主键
     * @return 结果
     */
    @Override
    public int deleteAllocCanteenByCanteenId(Long canteenId) {
        return allocCanteenMapper.deleteAllocCanteenByCanteenId(canteenId);
    }

    public static void main(String[] args) {
        BigDecimal bigDecimal = new BigDecimal("123.45");
        long longValue = bigDecimal.multiply(new BigDecimal(100)).longValue();
        System.out.println(longValue);
        System.out.println(GlobalConstants.TENANT_ID + "_" + UUID.randomUUID().toString().replaceAll("-",""));
    }
}
