package com.bonus.canteen.core.alloc.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.core.alloc.domain.AllocCanteen;
import com.bonus.canteen.core.alloc.service.IAllocCanteenService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 食堂信息Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "食堂信息接口")
@RestController
@RequestMapping("/alloc_canteen")
public class AllocCanteenController extends BaseController {
    @Autowired
    private IAllocCanteenService allocCanteenService;

    /**
     * 查询食堂信息列表
     */
    @ApiOperation(value = "查询食堂信息列表")
    //@RequiresPermissions("alloc:canteen:list")
    @GetMapping("/list")
    public TableDataInfo list(AllocCanteen allocCanteen) {
        if (allocCanteen.isPagenation()) {
            startPage();
        }
        List<AllocCanteen> list = allocCanteenService.selectAllocCanteenList(allocCanteen);
        return getDataTable(list);
    }

    /**
     * 导出食堂信息列表
     */
    @ApiOperation(value = "导出食堂信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:canteen:export")
    @SysLog(title = "食堂信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出食堂信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, AllocCanteen allocCanteen) {
        List<AllocCanteen> list = allocCanteenService.selectAllocCanteenList(allocCanteen);
        ExcelUtil<AllocCanteen> util = new ExcelUtil<AllocCanteen>(AllocCanteen.class);
        util.exportExcel(response, list, "食堂信息数据");
    }

    /**
     * 获取食堂信息详细信息
     */
    @ApiOperation(value = "获取食堂信息详细信息")
    //@RequiresPermissions("alloc:canteen:query")
    @GetMapping(value = "/{canteenId}")
    public AjaxResult getInfo(@PathVariable("canteenId") Long canteenId) {
        return success(allocCanteenService.selectAllocCanteenByCanteenId(canteenId));
    }

    /**
     * 新增食堂信息
     */
    @ApiOperation(value = "新增食堂信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:canteen:add")
    @SysLog(title = "食堂信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增食堂信息")
    @PostMapping
    public AjaxResult add(@RequestBody AllocCanteen allocCanteen) {
        try {
            return toAjax(allocCanteenService.insertAllocCanteen(allocCanteen));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改食堂信息
     */
    @ApiOperation(value = "修改食堂信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:canteen:edit")
    @SysLog(title = "食堂信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改食堂信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody AllocCanteen allocCanteen) {
        try {
            return toAjax(allocCanteenService.updateAllocCanteen(allocCanteen));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除食堂信息
     */
    @ApiOperation(value = "删除食堂信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:canteen:remove")
    @SysLog(title = "食堂信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除食堂信息")
	@PostMapping("/del/{canteenIds}")
    public AjaxResult remove(@PathVariable Long[] canteenIds) {
        return toAjax(allocCanteenService.deleteAllocCanteenByCanteenIds(canteenIds));
    }
}
